==> py-dss-interface-1.0.2.tar.gz: py-dss-interface-1.0.2/tests/py_dss_interface/test_dssexecutive.py <==
# -*- coding: utf-8 -*-
# @Time    : 8/26/2021 09:31 PM
# @Author  : Rodolfo Londero
# @Email   : rodolfpl@gmail.com
# @File    : test_dssexecutive.py
# @Software: PyCharm


import pytest


class TestDSSExecutive13Bus:

    @pytest.fixture(scope='function')
    def dss(self, solve_snap_13bus):
        dss = solve_snap_13bus

        return dss

    # ===================================================================
    # Integer methods
    # ===================================================================
    def test_executive_num_commands(self, dss):
        expected = 129
        actual = dss.executive_num_commands()
        assert actual == expected

    def test_executive_num_options(self, dss):
        expected = 134
        actual = dss.executive_num_options()
        assert actual == expected

    # ===================================================================
    # String methods
    # ===================================================================
    def test_executive_command(self, dss):
        expected = "New"
        actual = dss.executive_command("1")
        assert actual == expected

    def test_executive_option(self, dss):
        expected = "type"
        actual = dss.executive_option("1")
        assert actual == expected

    def test_executive_command_help(self, dss):
        expected = "Continuation of editing on the active object."
        actual = dss.executive_command_help("3")
        assert actual == expected

    def test_executive_option_help(self, dss):
        expected = "Sets the active DSS class type.  Same as Class=..."
        actual = dss.executive_option_help("1")
        assert actual == expected

    def test_executive_option_value(self, dss):
        expected = "Line"
        actual = dss.executive_option_value("1")
        assert actual == expected

==> py-dss-interface-2.0.1.tar.gz: py-dss-interface-2.0.1/tests/py_dss_interface/test_dssexecutive.py <==
# -*- coding: utf-8 -*-
# @Time    : 8/26/2021 09:31 PM
# @Author  : Rodolfo Londero
# @Email   : rodolfpl@gmail.com
# @File    : test_dssexecutive.py
# @Software: PyCharm


import pytest


class TestDSSExecutive13Bus:

    @pytest.fixture(scope='function')
    def dss(self, solve_snap_13bus):
        return solve_snap_13bus

    # ===================================================================
    # Integer methods
    # ===================================================================
    def test_executive_num_commands(self, dss):
        expected = 132
        actual = dss.dssexecutive.num_commands
        assert actual == expected

    def test_executive_num_options(self, dss):
        expected = 138
        actual = dss.dssexecutive.num_options
        assert actual == expected

    # ===================================================================
    # String methods
    # ===================================================================
    def test_executive_command(self, dss):
        expected = "New"
        actual = dss.dssexecutive.command("1")
        assert actual == expected

    def test_executive_option(self, dss):
        expected = "type"
        actual = dss.dssexecutive.option("1")
        assert actual == expected

    def test_executive_command_help(self, dss):
        expected = "Continuation of editing on the active object."
        actual = dss.dssexecutive.command_help("3")
        assert actual == expected

    def test_executive_option_help(self, dss):
        expected = "Sets the active DSS class type.  Same as Class=..."
        actual = dss.dssexecutive.option_help("1")
        assert actual == expected

    def test_executive_option_value(self, dss):
        expected = "Line"
        actual = dss.dssexecutive.option_value("1")
        assert actual == expected
